@@ -11,12 +11,12 @@ require Exporter;
 
 our @ISA = qw(Exporter AudioFile::Info Template::Plugin);
 
-our $VERSION = '0.01';
+our $VERSION = '1.5.1';
 
 sub new {
-  my ($class, $context, $file) = @_;
+  my ($class, $context, $file, $params) = @_;
 
-  my $self = $class->SUPER::new($file);
+  my $self = $class->SUPER::new($file, $params);
 
   return $self;
 }
@@ -72,9 +72,16 @@ like this.
 
     $tt->process('song.tt', { file => $_ })
       or die $tt->error;
+  }
 
 There are, of course, many other ways to do it.
 
+=head1 METHODS
+
+=head2 new
+
+Constructor for this object. Simply delegates to AudioFile::Info.
+
 =head1 SEE ALSO
 
 =over 4
